# encoding: utf-8
#
# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from gs2_core_client.Gs2Constant import Gs2Constant
from gs2_core_client.AbstractGs2Client import AbstractGs2Client
from aws_sdk_for_serverless.common import url_encoder


class Gs2GachaClient(AbstractGs2Client):

    ENDPOINT = "gacha"

    def __init__(self, credential, region):
        """
        コンストラクタ
        :param credential: 認証情報
        :type credential: IGs2Credential
        :param region: GS2リージョン
        :type region: str
        """
        super(Gs2GachaClient, self).__init__(credential, region)

    def get_current_gacha_master(self, request):
        """
        公開されているガチャマスタを取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.GetCurrentGachaMasterRequest.GetCurrentGachaMasterRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.GetCurrentGachaMasterResult.GetCurrentGachaMasterResult
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.GetCurrentGachaMasterRequest import GetCurrentGachaMasterRequest

        from gs2_gacha_client.control.GetCurrentGachaMasterResult import GetCurrentGachaMasterResult
        return GetCurrentGachaMasterResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/gacha/master",
            service=self.ENDPOINT,
            component=GetCurrentGachaMasterRequest.Constant.MODULE,
            target_function=GetCurrentGachaMasterRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def update_current_gacha_master(self, request):
        """
        公開するガチャマスタを更新します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.UpdateCurrentGachaMasterRequest.UpdateCurrentGachaMasterRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.UpdateCurrentGachaMasterResult.UpdateCurrentGachaMasterResult
        """
        body = { 
            "settings": request.get_settings(),
        }

        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.UpdateCurrentGachaMasterRequest import UpdateCurrentGachaMasterRequest
        from gs2_gacha_client.control.UpdateCurrentGachaMasterResult import UpdateCurrentGachaMasterResult
        return UpdateCurrentGachaMasterResult(self._do_post_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/gacha/master",
            service=self.ENDPOINT,
            component=UpdateCurrentGachaMasterRequest.Constant.MODULE,
            target_function=UpdateCurrentGachaMasterRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def create_gacha_master(self, request):
        """
        ガチャを新規作成します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.CreateGachaMasterRequest.CreateGachaMasterRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.CreateGachaMasterResult.CreateGachaMasterResult
        """
        body = { 
            "name": request.get_name(),
            "prizeTableNames": request.get_prize_table_names(),
        }

        if request.get_meta() is not None:
            body["meta"] = request.get_meta()
        if request.get_prize_job_queue_name() is not None:
            body["prizeJobQueueName"] = request.get_prize_job_queue_name()
        if request.get_prize_job_queue_script_name() is not None:
            body["prizeJobQueueScriptName"] = request.get_prize_job_queue_script_name()
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.CreateGachaMasterRequest import CreateGachaMasterRequest
        from gs2_gacha_client.control.CreateGachaMasterResult import CreateGachaMasterResult
        return CreateGachaMasterResult(self._do_post_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/master/gacha",
            service=self.ENDPOINT,
            component=CreateGachaMasterRequest.Constant.MODULE,
            target_function=CreateGachaMasterRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def delete_gacha_master(self, request):
        """
        ガチャを削除します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.DeleteGachaMasterRequest.DeleteGachaMasterRequest
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.DeleteGachaMasterRequest import DeleteGachaMasterRequest
        self._do_delete_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/master/gacha/" + str(("null" if request.get_gacha_name() is None or request.get_gacha_name() == "" else request.get_gacha_name())) + "",
            service=self.ENDPOINT,
            component=DeleteGachaMasterRequest.Constant.MODULE,
            target_function=DeleteGachaMasterRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        )

    def describe_gacha_master(self, request):
        """
        ガチャの一覧を取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.DescribeGachaMasterRequest.DescribeGachaMasterRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.DescribeGachaMasterResult.DescribeGachaMasterResult
        """
        query_strings = {}
        if request.get_page_token() is not None:
            query_strings['pageToken'] = request.get_page_token()
        if request.get_limit() is not None:
            query_strings['limit'] = request.get_limit()
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.DescribeGachaMasterRequest import DescribeGachaMasterRequest

        from gs2_gacha_client.control.DescribeGachaMasterResult import DescribeGachaMasterResult
        return DescribeGachaMasterResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/master/gacha",
            service=self.ENDPOINT,
            component=DescribeGachaMasterRequest.Constant.MODULE,
            target_function=DescribeGachaMasterRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def get_gacha_master(self, request):
        """
        ガチャを取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.GetGachaMasterRequest.GetGachaMasterRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.GetGachaMasterResult.GetGachaMasterResult
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.GetGachaMasterRequest import GetGachaMasterRequest

        from gs2_gacha_client.control.GetGachaMasterResult import GetGachaMasterResult
        return GetGachaMasterResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/master/gacha/" + str(("null" if request.get_gacha_name() is None or request.get_gacha_name() == "" else request.get_gacha_name())) + "",
            service=self.ENDPOINT,
            component=GetGachaMasterRequest.Constant.MODULE,
            target_function=GetGachaMasterRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def update_gacha_master(self, request):
        """
        ガチャを更新します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.UpdateGachaMasterRequest.UpdateGachaMasterRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.UpdateGachaMasterResult.UpdateGachaMasterResult
        """
        body = { 
            "prizeTableNames": request.get_prize_table_names(),
        }
        if request.get_meta() is not None:
            body["meta"] = request.get_meta()
        if request.get_prize_job_queue_name() is not None:
            body["prizeJobQueueName"] = request.get_prize_job_queue_name()
        if request.get_prize_job_queue_script_name() is not None:
            body["prizeJobQueueScriptName"] = request.get_prize_job_queue_script_name()
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.UpdateGachaMasterRequest import UpdateGachaMasterRequest
        from gs2_gacha_client.control.UpdateGachaMasterResult import UpdateGachaMasterResult
        return UpdateGachaMasterResult(self._do_put_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/master/gacha/" + str(("null" if request.get_gacha_name() is None or request.get_gacha_name() == "" else request.get_gacha_name())) + "",
            service=self.ENDPOINT,
            component=UpdateGachaMasterRequest.Constant.MODULE,
            target_function=UpdateGachaMasterRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def create_gacha_pool(self, request):
        """
        ガチャプールを新規作成します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.CreateGachaPoolRequest.CreateGachaPoolRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.CreateGachaPoolResult.CreateGachaPoolResult
        """
        body = { 
            "name": request.get_name(),
        }

        if request.get_description() is not None:
            body["description"] = request.get_description()
        if request.get_public_draw_rate() is not None:
            body["publicDrawRate"] = request.get_public_draw_rate()
        if request.get_allow_access_gacha_info() is not None:
            body["allowAccessGachaInfo"] = request.get_allow_access_gacha_info()
        if request.get_restrict() is not None:
            body["restrict"] = request.get_restrict()
        if request.get_draw_prize_trigger_script() is not None:
            body["drawPrizeTriggerScript"] = request.get_draw_prize_trigger_script()
        if request.get_draw_prize_done_trigger_script() is not None:
            body["drawPrizeDoneTriggerScript"] = request.get_draw_prize_done_trigger_script()
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.CreateGachaPoolRequest import CreateGachaPoolRequest
        from gs2_gacha_client.control.CreateGachaPoolResult import CreateGachaPoolResult
        return CreateGachaPoolResult(self._do_post_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool",
            service=self.ENDPOINT,
            component=CreateGachaPoolRequest.Constant.MODULE,
            target_function=CreateGachaPoolRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def delete_gacha_pool(self, request):
        """
        ガチャプールを削除します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.DeleteGachaPoolRequest.DeleteGachaPoolRequest
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.DeleteGachaPoolRequest import DeleteGachaPoolRequest
        self._do_delete_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "",
            service=self.ENDPOINT,
            component=DeleteGachaPoolRequest.Constant.MODULE,
            target_function=DeleteGachaPoolRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        )

    def describe_gacha_pool(self, request):
        """
        ガチャプールの一覧を取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.DescribeGachaPoolRequest.DescribeGachaPoolRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.DescribeGachaPoolResult.DescribeGachaPoolResult
        """
        query_strings = {}
        if request.get_page_token() is not None:
            query_strings['pageToken'] = request.get_page_token()
        if request.get_limit() is not None:
            query_strings['limit'] = request.get_limit()
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.DescribeGachaPoolRequest import DescribeGachaPoolRequest

        from gs2_gacha_client.control.DescribeGachaPoolResult import DescribeGachaPoolResult
        return DescribeGachaPoolResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool",
            service=self.ENDPOINT,
            component=DescribeGachaPoolRequest.Constant.MODULE,
            target_function=DescribeGachaPoolRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def get_gacha_pool(self, request):
        """
        ガチャプールを取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.GetGachaPoolRequest.GetGachaPoolRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.GetGachaPoolResult.GetGachaPoolResult
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.GetGachaPoolRequest import GetGachaPoolRequest

        from gs2_gacha_client.control.GetGachaPoolResult import GetGachaPoolResult
        return GetGachaPoolResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "",
            service=self.ENDPOINT,
            component=GetGachaPoolRequest.Constant.MODULE,
            target_function=GetGachaPoolRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def get_gacha_pool_status(self, request):
        """
        ガチャプールの状態を取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.GetGachaPoolStatusRequest.GetGachaPoolStatusRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.GetGachaPoolStatusResult.GetGachaPoolStatusResult
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.GetGachaPoolStatusRequest import GetGachaPoolStatusRequest

        from gs2_gacha_client.control.GetGachaPoolStatusResult import GetGachaPoolStatusResult
        return GetGachaPoolStatusResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/status",
            service=self.ENDPOINT,
            component=GetGachaPoolStatusRequest.Constant.MODULE,
            target_function=GetGachaPoolStatusRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def update_gacha_pool(self, request):
        """
        ガチャプールを更新します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.UpdateGachaPoolRequest.UpdateGachaPoolRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.UpdateGachaPoolResult.UpdateGachaPoolResult
        """
        body = { 
        }
        if request.get_description() is not None:
            body["description"] = request.get_description()
        if request.get_public_draw_rate() is not None:
            body["publicDrawRate"] = request.get_public_draw_rate()
        if request.get_allow_access_gacha_info() is not None:
            body["allowAccessGachaInfo"] = request.get_allow_access_gacha_info()
        if request.get_restrict() is not None:
            body["restrict"] = request.get_restrict()
        if request.get_draw_prize_trigger_script() is not None:
            body["drawPrizeTriggerScript"] = request.get_draw_prize_trigger_script()
        if request.get_draw_prize_done_trigger_script() is not None:
            body["drawPrizeDoneTriggerScript"] = request.get_draw_prize_done_trigger_script()
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.UpdateGachaPoolRequest import UpdateGachaPoolRequest
        from gs2_gacha_client.control.UpdateGachaPoolResult import UpdateGachaPoolResult
        return UpdateGachaPoolResult(self._do_put_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "",
            service=self.ENDPOINT,
            component=UpdateGachaPoolRequest.Constant.MODULE,
            target_function=UpdateGachaPoolRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def describe_gacha(self, request):
        """
        公開されているガチャ一覧を取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.DescribeGachaRequest.DescribeGachaRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.DescribeGachaResult.DescribeGachaResult
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.DescribeGachaRequest import DescribeGachaRequest

        from gs2_gacha_client.control.DescribeGachaResult import DescribeGachaResult
        return DescribeGachaResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/gacha",
            service=self.ENDPOINT,
            component=DescribeGachaRequest.Constant.MODULE,
            target_function=DescribeGachaRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def detail_probability(self, request):
        """
        リソース毎のガチャの排出確率を取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.DetailProbabilityRequest.DetailProbabilityRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.DetailProbabilityResult.DetailProbabilityResult
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.DetailProbabilityRequest import DetailProbabilityRequest

        from gs2_gacha_client.control.DetailProbabilityResult import DetailProbabilityResult
        return DetailProbabilityResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/gacha/" + str(("null" if request.get_gacha_name() is None or request.get_gacha_name() == "" else request.get_gacha_name())) + "/probability/" + str(("null" if request.get_draw_time() is None or request.get_draw_time() == "" else request.get_draw_time())) + "/detail",
            service=self.ENDPOINT,
            component=DetailProbabilityRequest.Constant.MODULE,
            target_function=DetailProbabilityRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def do_gacha(self, request):
        """
        ガチャを実行します。<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.DoGachaRequest.DoGachaRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.DoGachaResult.DoGachaResult
        """
        body = { 
        }

        if request.get_context() is not None:
            body["context"] = request.get_context()
        headers = {}
        if request.get_access_token() is not None:
            headers["X-GS2-ACCESS-TOKEN"] = request.get_access_token()
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.DoGachaRequest import DoGachaRequest
        from gs2_gacha_client.control.DoGachaResult import DoGachaResult
        return DoGachaResult(self._do_post_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/gacha/" + str(("null" if request.get_gacha_name() is None or request.get_gacha_name() == "" else request.get_gacha_name())) + "",
            service=self.ENDPOINT,
            component=DoGachaRequest.Constant.MODULE,
            target_function=DoGachaRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def do_gacha_by_stamp_sheet(self, request):
        """
        スタンプシートを使用してガチャを実行します。<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.DoGachaByStampSheetRequest.DoGachaByStampSheetRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.DoGachaByStampSheetResult.DoGachaByStampSheetResult
        """
        body = { 
            "sheet": request.get_sheet(),
            "keyName": request.get_key_name(),
        }

        headers = {}
        if request.get_access_token() is not None:
            headers["X-GS2-ACCESS-TOKEN"] = request.get_access_token()
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.DoGachaByStampSheetRequest import DoGachaByStampSheetRequest
        from gs2_gacha_client.control.DoGachaByStampSheetResult import DoGachaByStampSheetResult
        return DoGachaByStampSheetResult(self._do_post_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gacha",
            service=self.ENDPOINT,
            component=DoGachaByStampSheetRequest.Constant.MODULE,
            target_function=DoGachaByStampSheetRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def get_gacha(self, request):
        """
        公開されているガチャを取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.GetGachaRequest.GetGachaRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.GetGachaResult.GetGachaResult
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.GetGachaRequest import GetGachaRequest

        from gs2_gacha_client.control.GetGachaResult import GetGachaResult
        return GetGachaResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/gacha/" + str(("null" if request.get_gacha_name() is None or request.get_gacha_name() == "" else request.get_gacha_name())) + "",
            service=self.ENDPOINT,
            component=GetGachaRequest.Constant.MODULE,
            target_function=GetGachaRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def get_probability(self, request):
        """
        レアリティ毎のガチャの排出確率を取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.GetProbabilityRequest.GetProbabilityRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.GetProbabilityResult.GetProbabilityResult
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.GetProbabilityRequest import GetProbabilityRequest

        from gs2_gacha_client.control.GetProbabilityResult import GetProbabilityResult
        return GetProbabilityResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/gacha/" + str(("null" if request.get_gacha_name() is None or request.get_gacha_name() == "" else request.get_gacha_name())) + "/probability/" + str(("null" if request.get_draw_time() is None or request.get_draw_time() == "" else request.get_draw_time())) + "",
            service=self.ENDPOINT,
            component=GetProbabilityRequest.Constant.MODULE,
            target_function=GetProbabilityRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def export_master(self, request):
        """
        ガチャマスターデータをエクスポートする<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.ExportMasterRequest.ExportMasterRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.ExportMasterResult.ExportMasterResult
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.ExportMasterRequest import ExportMasterRequest

        from gs2_gacha_client.control.ExportMasterResult import ExportMasterResult
        return ExportMasterResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/master",
            service=self.ENDPOINT,
            component=ExportMasterRequest.Constant.MODULE,
            target_function=ExportMasterRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def create_prize_master(self, request):
        """
        景品を新規作成します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.CreatePrizeMasterRequest.CreatePrizeMasterRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.CreatePrizeMasterResult.CreatePrizeMasterResult
        """
        body = { 
            "resourceId": request.get_resource_id(),
            "weight": request.get_weight(),
        }

        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.CreatePrizeMasterRequest import CreatePrizeMasterRequest
        from gs2_gacha_client.control.CreatePrizeMasterResult import CreatePrizeMasterResult
        return CreatePrizeMasterResult(self._do_post_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/master/prizeTable/" + str(("null" if request.get_prize_table_name() is None or request.get_prize_table_name() == "" else request.get_prize_table_name())) + "/rarity/" + str(("null" if request.get_rarity_name() is None or request.get_rarity_name() == "" else request.get_rarity_name())) + "/prize",
            service=self.ENDPOINT,
            component=CreatePrizeMasterRequest.Constant.MODULE,
            target_function=CreatePrizeMasterRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def delete_prize_master(self, request):
        """
        景品を削除します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.DeletePrizeMasterRequest.DeletePrizeMasterRequest
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.DeletePrizeMasterRequest import DeletePrizeMasterRequest
        self._do_delete_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/master/prizeTable/" + str(("null" if request.get_prize_table_name() is None or request.get_prize_table_name() == "" else request.get_prize_table_name())) + "/rarity/" + str(("null" if request.get_rarity_name() is None or request.get_rarity_name() == "" else request.get_rarity_name())) + "/prize/" + str(("null" if request.get_resource_id() is None or request.get_resource_id() == "" else request.get_resource_id())) + "",
            service=self.ENDPOINT,
            component=DeletePrizeMasterRequest.Constant.MODULE,
            target_function=DeletePrizeMasterRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        )

    def describe_prize_master(self, request):
        """
        景品の一覧を取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.DescribePrizeMasterRequest.DescribePrizeMasterRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.DescribePrizeMasterResult.DescribePrizeMasterResult
        """
        query_strings = {}
        if request.get_page_token() is not None:
            query_strings['pageToken'] = request.get_page_token()
        if request.get_limit() is not None:
            query_strings['limit'] = request.get_limit()
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.DescribePrizeMasterRequest import DescribePrizeMasterRequest

        from gs2_gacha_client.control.DescribePrizeMasterResult import DescribePrizeMasterResult
        return DescribePrizeMasterResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/master/prizeTable/" + str(("null" if request.get_prize_table_name() is None or request.get_prize_table_name() == "" else request.get_prize_table_name())) + "/rarity/" + str(("null" if request.get_rarity_name() is None or request.get_rarity_name() == "" else request.get_rarity_name())) + "/prize",
            service=self.ENDPOINT,
            component=DescribePrizeMasterRequest.Constant.MODULE,
            target_function=DescribePrizeMasterRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def get_prize_master(self, request):
        """
        景品を取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.GetPrizeMasterRequest.GetPrizeMasterRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.GetPrizeMasterResult.GetPrizeMasterResult
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.GetPrizeMasterRequest import GetPrizeMasterRequest

        from gs2_gacha_client.control.GetPrizeMasterResult import GetPrizeMasterResult
        return GetPrizeMasterResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/master/prizeTable/" + str(("null" if request.get_prize_table_name() is None or request.get_prize_table_name() == "" else request.get_prize_table_name())) + "/rarity/" + str(("null" if request.get_rarity_name() is None or request.get_rarity_name() == "" else request.get_rarity_name())) + "/prize/" + str(("null" if request.get_resource_id() is None or request.get_resource_id() == "" else request.get_resource_id())) + "",
            service=self.ENDPOINT,
            component=GetPrizeMasterRequest.Constant.MODULE,
            target_function=GetPrizeMasterRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def update_prize_master(self, request):
        """
        景品を更新します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.UpdatePrizeMasterRequest.UpdatePrizeMasterRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.UpdatePrizeMasterResult.UpdatePrizeMasterResult
        """
        body = { 
            "weight": request.get_weight(),
        }
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.UpdatePrizeMasterRequest import UpdatePrizeMasterRequest
        from gs2_gacha_client.control.UpdatePrizeMasterResult import UpdatePrizeMasterResult
        return UpdatePrizeMasterResult(self._do_put_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/master/prizeTable/" + str(("null" if request.get_prize_table_name() is None or request.get_prize_table_name() == "" else request.get_prize_table_name())) + "/rarity/" + str(("null" if request.get_rarity_name() is None or request.get_rarity_name() == "" else request.get_rarity_name())) + "/prize/" + str(("null" if request.get_resource_id() is None or request.get_resource_id() == "" else request.get_resource_id())) + "",
            service=self.ENDPOINT,
            component=UpdatePrizeMasterRequest.Constant.MODULE,
            target_function=UpdatePrizeMasterRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def create_prize_table_master(self, request):
        """
        排出確率テーブルを新規作成します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.CreatePrizeTableMasterRequest.CreatePrizeTableMasterRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.CreatePrizeTableMasterResult.CreatePrizeTableMasterResult
        """
        body = { 
            "name": request.get_name(),
        }

        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.CreatePrizeTableMasterRequest import CreatePrizeTableMasterRequest
        from gs2_gacha_client.control.CreatePrizeTableMasterResult import CreatePrizeTableMasterResult
        return CreatePrizeTableMasterResult(self._do_post_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/master/prizeTable",
            service=self.ENDPOINT,
            component=CreatePrizeTableMasterRequest.Constant.MODULE,
            target_function=CreatePrizeTableMasterRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def delete_prize_table_master(self, request):
        """
        排出確率テーブルを削除します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.DeletePrizeTableMasterRequest.DeletePrizeTableMasterRequest
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.DeletePrizeTableMasterRequest import DeletePrizeTableMasterRequest
        self._do_delete_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/master/prizeTable/" + str(("null" if request.get_prize_table_name() is None or request.get_prize_table_name() == "" else request.get_prize_table_name())) + "",
            service=self.ENDPOINT,
            component=DeletePrizeTableMasterRequest.Constant.MODULE,
            target_function=DeletePrizeTableMasterRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        )

    def describe_prize_table_master(self, request):
        """
        排出確率テーブルの一覧を取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.DescribePrizeTableMasterRequest.DescribePrizeTableMasterRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.DescribePrizeTableMasterResult.DescribePrizeTableMasterResult
        """
        query_strings = {}
        if request.get_page_token() is not None:
            query_strings['pageToken'] = request.get_page_token()
        if request.get_limit() is not None:
            query_strings['limit'] = request.get_limit()
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.DescribePrizeTableMasterRequest import DescribePrizeTableMasterRequest

        from gs2_gacha_client.control.DescribePrizeTableMasterResult import DescribePrizeTableMasterResult
        return DescribePrizeTableMasterResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/master/prizeTable",
            service=self.ENDPOINT,
            component=DescribePrizeTableMasterRequest.Constant.MODULE,
            target_function=DescribePrizeTableMasterRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def get_prize_table_master(self, request):
        """
        排出確率テーブルを取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.GetPrizeTableMasterRequest.GetPrizeTableMasterRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.GetPrizeTableMasterResult.GetPrizeTableMasterResult
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.GetPrizeTableMasterRequest import GetPrizeTableMasterRequest

        from gs2_gacha_client.control.GetPrizeTableMasterResult import GetPrizeTableMasterResult
        return GetPrizeTableMasterResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/master/prizeTable/" + str(("null" if request.get_prize_table_name() is None or request.get_prize_table_name() == "" else request.get_prize_table_name())) + "",
            service=self.ENDPOINT,
            component=GetPrizeTableMasterRequest.Constant.MODULE,
            target_function=GetPrizeTableMasterRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def create_rarity_master(self, request):
        """
        景品レアリティを新規作成します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.CreateRarityMasterRequest.CreateRarityMasterRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.CreateRarityMasterResult.CreateRarityMasterResult
        """
        body = { 
            "name": request.get_name(),
            "weight": request.get_weight(),
        }

        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.CreateRarityMasterRequest import CreateRarityMasterRequest
        from gs2_gacha_client.control.CreateRarityMasterResult import CreateRarityMasterResult
        return CreateRarityMasterResult(self._do_post_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/master/prizeTable/" + str(("null" if request.get_prize_table_name() is None or request.get_prize_table_name() == "" else request.get_prize_table_name())) + "/rarity",
            service=self.ENDPOINT,
            component=CreateRarityMasterRequest.Constant.MODULE,
            target_function=CreateRarityMasterRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))

    def delete_rarity_master(self, request):
        """
        景品レアリティを削除します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.DeleteRarityMasterRequest.DeleteRarityMasterRequest
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.DeleteRarityMasterRequest import DeleteRarityMasterRequest
        self._do_delete_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/master/prizeTable/" + str(("null" if request.get_prize_table_name() is None or request.get_prize_table_name() == "" else request.get_prize_table_name())) + "/rarity/" + str(("null" if request.get_rarity_name() is None or request.get_rarity_name() == "" else request.get_rarity_name())) + "",
            service=self.ENDPOINT,
            component=DeleteRarityMasterRequest.Constant.MODULE,
            target_function=DeleteRarityMasterRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        )

    def describe_rarity_master(self, request):
        """
        景品レアリティの一覧を取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.DescribeRarityMasterRequest.DescribeRarityMasterRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.DescribeRarityMasterResult.DescribeRarityMasterResult
        """
        query_strings = {}
        if request.get_page_token() is not None:
            query_strings['pageToken'] = request.get_page_token()
        if request.get_limit() is not None:
            query_strings['limit'] = request.get_limit()
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.DescribeRarityMasterRequest import DescribeRarityMasterRequest

        from gs2_gacha_client.control.DescribeRarityMasterResult import DescribeRarityMasterResult
        return DescribeRarityMasterResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/master/prizeTable/" + str(("null" if request.get_prize_table_name() is None or request.get_prize_table_name() == "" else request.get_prize_table_name())) + "/rarity",
            service=self.ENDPOINT,
            component=DescribeRarityMasterRequest.Constant.MODULE,
            target_function=DescribeRarityMasterRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def get_rarity_master(self, request):
        """
        景品レアリティを取得します<br>
        <br>:param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.GetRarityMasterRequest.GetRarityMasterRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.GetRarityMasterResult.GetRarityMasterResult
        """
        query_strings = {}
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.GetRarityMasterRequest import GetRarityMasterRequest

        from gs2_gacha_client.control.GetRarityMasterResult import GetRarityMasterResult
        return GetRarityMasterResult(self._do_get_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/master/prizeTable/" + str(("null" if request.get_prize_table_name() is None or request.get_prize_table_name() == "" else request.get_prize_table_name())) + "/rarity/" + str(("null" if request.get_rarity_name() is None or request.get_rarity_name() == "" else request.get_rarity_name())) + "",
            service=self.ENDPOINT,
            component=GetRarityMasterRequest.Constant.MODULE,
            target_function=GetRarityMasterRequest.Constant.FUNCTION,
            query_strings=query_strings,
            headers=headers
        ))

    def update_rarity_master(self, request):
        """
        景品レアリティを更新します<br>
        <br>
        :param request: リクエストパラメータ
        :type request: gs2_gacha_client.control.UpdateRarityMasterRequest.UpdateRarityMasterRequest
        :return: 結果
        :rtype: gs2_gacha_client.control.UpdateRarityMasterResult.UpdateRarityMasterResult
        """
        body = { 
            "weight": request.get_weight(),
        }
        headers = {}
        if request.get_request_id() is not None:
            headers["X-GS2-REQUEST-ID"] = request.get_request_id()
        from gs2_gacha_client.control.UpdateRarityMasterRequest import UpdateRarityMasterRequest
        from gs2_gacha_client.control.UpdateRarityMasterResult import UpdateRarityMasterResult
        return UpdateRarityMasterResult(self._do_put_request(
            url=Gs2Constant.ENDPOINT_HOST + "/gachaPool/" + str(("null" if request.get_gacha_pool_name() is None or request.get_gacha_pool_name() == "" else request.get_gacha_pool_name())) + "/master/prizeTable/" + str(("null" if request.get_prize_table_name() is None or request.get_prize_table_name() == "" else request.get_prize_table_name())) + "/rarity/" + str(("null" if request.get_rarity_name() is None or request.get_rarity_name() == "" else request.get_rarity_name())) + "",
            service=self.ENDPOINT,
            component=UpdateRarityMasterRequest.Constant.MODULE,
            target_function=UpdateRarityMasterRequest.Constant.FUNCTION,
            body=body,
            headers=headers
        ))
