# encoding: utf-8
#
# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from gs2_core_client.Gs2BasicRequest import Gs2BasicRequest
from gs2_gacha_client.Gs2Gacha import Gs2Gacha


class CreateGachaPoolRequest(Gs2BasicRequest):

    class Constant(Gs2Gacha):
        FUNCTION = "CreateGachaPool"

    def __init__(self, params=None):
        """
        コンストラクタ
        :param params: 辞書配列形式のパラメータ初期値リスト
        :type params: dict|None
        """
        super(CreateGachaPoolRequest, self).__init__(params)
        if params is None:
            self.__name = None
        else:
            self.set_name(params['name'] if 'name' in params.keys() else None)
        if params is None:
            self.__description = None
        else:
            self.set_description(params['description'] if 'description' in params.keys() else None)
        if params is None:
            self.__public_draw_rate = None
        else:
            self.set_public_draw_rate(params['publicDrawRate'] if 'publicDrawRate' in params.keys() else None)
        if params is None:
            self.__allow_access_gacha_info = None
        else:
            self.set_allow_access_gacha_info(params['allowAccessGachaInfo'] if 'allowAccessGachaInfo' in params.keys() else None)
        if params is None:
            self.__restrict = None
        else:
            self.set_restrict(params['restrict'] if 'restrict' in params.keys() else None)
        if params is None:
            self.__draw_prize_trigger_script = None
        else:
            self.set_draw_prize_trigger_script(params['drawPrizeTriggerScript'] if 'drawPrizeTriggerScript' in params.keys() else None)
        if params is None:
            self.__draw_prize_done_trigger_script = None
        else:
            self.set_draw_prize_done_trigger_script(params['drawPrizeDoneTriggerScript'] if 'drawPrizeDoneTriggerScript' in params.keys() else None)

    def get_name(self):
        """
        ガチャプール名を取得
        :return: ガチャプール名
        :rtype: unicode
        """
        return self.__name

    def set_name(self, name):
        """
        ガチャプール名を設定
        :param name: ガチャプール名
        :type name: unicode
        """
        if name is not None and not (isinstance(name, str) or isinstance(name, unicode)):
            raise TypeError(type(name))
        self.__name = name

    def with_name(self, name):
        """
        ガチャプール名を設定
        :param name: ガチャプール名
        :type name: unicode
        :return: this
        :rtype: CreateGachaPoolRequest
        """
        self.set_name(name)
        return self

    def get_description(self):
        """
        説明文を取得
        :return: 説明文
        :rtype: unicode
        """
        return self.__description

    def set_description(self, description):
        """
        説明文を設定
        :param description: 説明文
        :type description: unicode
        """
        if description is not None and not (isinstance(description, str) or isinstance(description, unicode)):
            raise TypeError(type(description))
        self.__description = description

    def with_description(self, description):
        """
        説明文を設定
        :param description: 説明文
        :type description: unicode
        :return: this
        :rtype: CreateGachaPoolRequest
        """
        self.set_description(description)
        return self

    def get_public_draw_rate(self):
        """
        排出確率を公開するかを取得
        :return: 排出確率を公開するか
        :rtype: unicode
        """
        return self.__public_draw_rate

    def set_public_draw_rate(self, public_draw_rate):
        """
        排出確率を公開するかを設定
        :param public_draw_rate: 排出確率を公開するか
        :type public_draw_rate: unicode
        """
        if public_draw_rate is not None and not (isinstance(public_draw_rate, str) or isinstance(public_draw_rate, unicode)):
            raise TypeError(type(public_draw_rate))
        self.__public_draw_rate = public_draw_rate

    def with_public_draw_rate(self, public_draw_rate):
        """
        排出確率を公開するかを設定
        :param public_draw_rate: 排出確率を公開するか
        :type public_draw_rate: unicode
        :return: this
        :rtype: CreateGachaPoolRequest
        """
        self.set_public_draw_rate(public_draw_rate)
        return self

    def get_allow_access_gacha_info(self):
        """
        ガチャ一覧の取得を許すかを取得
        :return: ガチャ一覧の取得を許すか
        :rtype: unicode
        """
        return self.__allow_access_gacha_info

    def set_allow_access_gacha_info(self, allow_access_gacha_info):
        """
        ガチャ一覧の取得を許すかを設定
        :param allow_access_gacha_info: ガチャ一覧の取得を許すか
        :type allow_access_gacha_info: unicode
        """
        if allow_access_gacha_info is not None and not (isinstance(allow_access_gacha_info, str) or isinstance(allow_access_gacha_info, unicode)):
            raise TypeError(type(allow_access_gacha_info))
        self.__allow_access_gacha_info = allow_access_gacha_info

    def with_allow_access_gacha_info(self, allow_access_gacha_info):
        """
        ガチャ一覧の取得を許すかを設定
        :param allow_access_gacha_info: ガチャ一覧の取得を許すか
        :type allow_access_gacha_info: unicode
        :return: this
        :rtype: CreateGachaPoolRequest
        """
        self.set_allow_access_gacha_info(allow_access_gacha_info)
        return self

    def get_restrict(self):
        """
        抽選実行を制限するかを取得
        :return: 抽選実行を制限するか
        :rtype: unicode
        """
        return self.__restrict

    def set_restrict(self, restrict):
        """
        抽選実行を制限するかを設定
        :param restrict: 抽選実行を制限するか
        :type restrict: unicode
        """
        if restrict is not None and not (isinstance(restrict, str) or isinstance(restrict, unicode)):
            raise TypeError(type(restrict))
        self.__restrict = restrict

    def with_restrict(self, restrict):
        """
        抽選実行を制限するかを設定
        :param restrict: 抽選実行を制限するか
        :type restrict: unicode
        :return: this
        :rtype: CreateGachaPoolRequest
        """
        self.set_restrict(restrict)
        return self

    def get_draw_prize_trigger_script(self):
        """
        排出判定時 に実行されるGS2-Scriptを取得
        :return: 排出判定時 に実行されるGS2-Script
        :rtype: unicode
        """
        return self.__draw_prize_trigger_script

    def set_draw_prize_trigger_script(self, draw_prize_trigger_script):
        """
        排出判定時 に実行されるGS2-Scriptを設定
        :param draw_prize_trigger_script: 排出判定時 に実行されるGS2-Script
        :type draw_prize_trigger_script: unicode
        """
        if draw_prize_trigger_script is not None and not (isinstance(draw_prize_trigger_script, str) or isinstance(draw_prize_trigger_script, unicode)):
            raise TypeError(type(draw_prize_trigger_script))
        self.__draw_prize_trigger_script = draw_prize_trigger_script

    def with_draw_prize_trigger_script(self, draw_prize_trigger_script):
        """
        排出判定時 に実行されるGS2-Scriptを設定
        :param draw_prize_trigger_script: 排出判定時 に実行されるGS2-Script
        :type draw_prize_trigger_script: unicode
        :return: this
        :rtype: CreateGachaPoolRequest
        """
        self.set_draw_prize_trigger_script(draw_prize_trigger_script)
        return self

    def get_draw_prize_done_trigger_script(self):
        """
        排出判定完了時 に実行されるGS2-Scriptを取得
        :return: 排出判定完了時 に実行されるGS2-Script
        :rtype: unicode
        """
        return self.__draw_prize_done_trigger_script

    def set_draw_prize_done_trigger_script(self, draw_prize_done_trigger_script):
        """
        排出判定完了時 に実行されるGS2-Scriptを設定
        :param draw_prize_done_trigger_script: 排出判定完了時 に実行されるGS2-Script
        :type draw_prize_done_trigger_script: unicode
        """
        if draw_prize_done_trigger_script is not None and not (isinstance(draw_prize_done_trigger_script, str) or isinstance(draw_prize_done_trigger_script, unicode)):
            raise TypeError(type(draw_prize_done_trigger_script))
        self.__draw_prize_done_trigger_script = draw_prize_done_trigger_script

    def with_draw_prize_done_trigger_script(self, draw_prize_done_trigger_script):
        """
        排出判定完了時 に実行されるGS2-Scriptを設定
        :param draw_prize_done_trigger_script: 排出判定完了時 に実行されるGS2-Script
        :type draw_prize_done_trigger_script: unicode
        :return: this
        :rtype: CreateGachaPoolRequest
        """
        self.set_draw_prize_done_trigger_script(draw_prize_done_trigger_script)
        return self
