# encoding: utf-8
#
# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from gs2_core_client.Gs2BasicRequest import Gs2BasicRequest
from gs2_gacha_client.Gs2Gacha import Gs2Gacha


class DeletePrizeTableMasterRequest(Gs2BasicRequest):

    class Constant(Gs2Gacha):
        FUNCTION = "DeletePrizeTableMaster"

    def __init__(self, params=None):
        """
        コンストラクタ
        :param params: 辞書配列形式のパラメータ初期値リスト
        :type params: dict|None
        """
        super(DeletePrizeTableMasterRequest, self).__init__(params)
        if params is None:
            self.__gacha_pool_name = None
        else:
            self.set_gacha_pool_name(params['gachaPoolName'] if 'gachaPoolName' in params.keys() else None)
        if params is None:
            self.__prize_table_name = None
        else:
            self.set_prize_table_name(params['prizeTableName'] if 'prizeTableName' in params.keys() else None)

    def get_gacha_pool_name(self):
        """
        ガチャプールの名前を指定します。を取得
        :return: ガチャプールの名前を指定します。
        :rtype: unicode
        """
        return self.__gacha_pool_name

    def set_gacha_pool_name(self, gacha_pool_name):
        """
        ガチャプールの名前を指定します。を設定
        :param gacha_pool_name: ガチャプールの名前を指定します。
        :type gacha_pool_name: unicode
        """
        if gacha_pool_name is not None and not (isinstance(gacha_pool_name, str) or isinstance(gacha_pool_name, unicode)):
            raise TypeError(type(gacha_pool_name))
        self.__gacha_pool_name = gacha_pool_name

    def with_gacha_pool_name(self, gacha_pool_name):
        """
        ガチャプールの名前を指定します。を設定
        :param gacha_pool_name: ガチャプールの名前を指定します。
        :type gacha_pool_name: unicode
        :return: this
        :rtype: DeletePrizeTableMasterRequest
        """
        self.set_gacha_pool_name(gacha_pool_name)
        return self

    def get_prize_table_name(self):
        """
        排出確率テーブルの名前を指定します。を取得
        :return: 排出確率テーブルの名前を指定します。
        :rtype: unicode
        """
        return self.__prize_table_name

    def set_prize_table_name(self, prize_table_name):
        """
        排出確率テーブルの名前を指定します。を設定
        :param prize_table_name: 排出確率テーブルの名前を指定します。
        :type prize_table_name: unicode
        """
        if prize_table_name is not None and not (isinstance(prize_table_name, str) or isinstance(prize_table_name, unicode)):
            raise TypeError(type(prize_table_name))
        self.__prize_table_name = prize_table_name

    def with_prize_table_name(self, prize_table_name):
        """
        排出確率テーブルの名前を指定します。を設定
        :param prize_table_name: 排出確率テーブルの名前を指定します。
        :type prize_table_name: unicode
        :return: this
        :rtype: DeletePrizeTableMasterRequest
        """
        self.set_prize_table_name(prize_table_name)
        return self
