# encoding: utf-8
#
# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from gs2_core_client.Gs2BasicRequest import Gs2BasicRequest
from gs2_gacha_client.Gs2Gacha import Gs2Gacha


class DescribePrizeMasterRequest(Gs2BasicRequest):

    class Constant(Gs2Gacha):
        FUNCTION = "DescribePrizeMaster"

    def __init__(self, params=None):
        """
        コンストラクタ
        :param params: 辞書配列形式のパラメータ初期値リスト
        :type params: dict|None
        """
        super(DescribePrizeMasterRequest, self).__init__(params)
        if params is None:
            self.__gacha_pool_name = None
        else:
            self.set_gacha_pool_name(params['gachaPoolName'] if 'gachaPoolName' in params.keys() else None)
        if params is None:
            self.__prize_table_name = None
        else:
            self.set_prize_table_name(params['prizeTableName'] if 'prizeTableName' in params.keys() else None)
        if params is None:
            self.__rarity_name = None
        else:
            self.set_rarity_name(params['rarityName'] if 'rarityName' in params.keys() else None)
        if params is None:
            self.__page_token = None
        else:
            self.set_page_token(params['pageToken'] if 'pageToken' in params.keys() else None)
        if params is None:
            self.__limit = None
        else:
            self.set_limit(params['limit'] if 'limit' in params.keys() else None)

    def get_gacha_pool_name(self):
        """
        ガチャプールの名前を指定します。を取得
        :return: ガチャプールの名前を指定します。
        :rtype: unicode
        """
        return self.__gacha_pool_name

    def set_gacha_pool_name(self, gacha_pool_name):
        """
        ガチャプールの名前を指定します。を設定
        :param gacha_pool_name: ガチャプールの名前を指定します。
        :type gacha_pool_name: unicode
        """
        if gacha_pool_name is not None and not (isinstance(gacha_pool_name, str) or isinstance(gacha_pool_name, unicode)):
            raise TypeError(type(gacha_pool_name))
        self.__gacha_pool_name = gacha_pool_name

    def with_gacha_pool_name(self, gacha_pool_name):
        """
        ガチャプールの名前を指定します。を設定
        :param gacha_pool_name: ガチャプールの名前を指定します。
        :type gacha_pool_name: unicode
        :return: this
        :rtype: DescribePrizeMasterRequest
        """
        self.set_gacha_pool_name(gacha_pool_name)
        return self

    def get_prize_table_name(self):
        """
        排出確率テーブルの名前を指定します。を取得
        :return: 排出確率テーブルの名前を指定します。
        :rtype: unicode
        """
        return self.__prize_table_name

    def set_prize_table_name(self, prize_table_name):
        """
        排出確率テーブルの名前を指定します。を設定
        :param prize_table_name: 排出確率テーブルの名前を指定します。
        :type prize_table_name: unicode
        """
        if prize_table_name is not None and not (isinstance(prize_table_name, str) or isinstance(prize_table_name, unicode)):
            raise TypeError(type(prize_table_name))
        self.__prize_table_name = prize_table_name

    def with_prize_table_name(self, prize_table_name):
        """
        排出確率テーブルの名前を指定します。を設定
        :param prize_table_name: 排出確率テーブルの名前を指定します。
        :type prize_table_name: unicode
        :return: this
        :rtype: DescribePrizeMasterRequest
        """
        self.set_prize_table_name(prize_table_name)
        return self

    def get_rarity_name(self):
        """
        景品レアリティの名前を指定します。を取得
        :return: 景品レアリティの名前を指定します。
        :rtype: unicode
        """
        return self.__rarity_name

    def set_rarity_name(self, rarity_name):
        """
        景品レアリティの名前を指定します。を設定
        :param rarity_name: 景品レアリティの名前を指定します。
        :type rarity_name: unicode
        """
        if rarity_name is not None and not (isinstance(rarity_name, str) or isinstance(rarity_name, unicode)):
            raise TypeError(type(rarity_name))
        self.__rarity_name = rarity_name

    def with_rarity_name(self, rarity_name):
        """
        景品レアリティの名前を指定します。を設定
        :param rarity_name: 景品レアリティの名前を指定します。
        :type rarity_name: unicode
        :return: this
        :rtype: DescribePrizeMasterRequest
        """
        self.set_rarity_name(rarity_name)
        return self

    def get_page_token(self):
        """
        データの取得を開始する位置を指定するトークンを取得
        :return: データの取得を開始する位置を指定するトークン
        :rtype: unicode
        """
        return self.__page_token

    def set_page_token(self, page_token):
        """
        データの取得を開始する位置を指定するトークンを設定
        :param page_token: データの取得を開始する位置を指定するトークン
        :type page_token: unicode
        """
        if page_token is not None and not (isinstance(page_token, str) or isinstance(page_token, unicode)):
            raise TypeError(type(page_token))
        self.__page_token = page_token

    def with_page_token(self, page_token):
        """
        データの取得を開始する位置を指定するトークンを設定
        :param page_token: データの取得を開始する位置を指定するトークン
        :type page_token: unicode
        :return: this
        :rtype: DescribePrizeMasterRequest
        """
        self.set_page_token(page_token)
        return self

    def get_limit(self):
        """
        データの取得件数を取得
        :return: データの取得件数
        :rtype: int
        """
        return self.__limit

    def set_limit(self, limit):
        """
        データの取得件数を設定
        :param limit: データの取得件数
        :type limit: int
        """
        if limit is not None and not isinstance(limit, int):
            raise TypeError(type(limit))
        self.__limit = limit

    def with_limit(self, limit):
        """
        データの取得件数を設定
        :param limit: データの取得件数
        :type limit: int
        :return: this
        :rtype: DescribePrizeMasterRequest
        """
        self.set_limit(limit)
        return self
