# encoding: utf-8
#
# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from gs2_core_client.Gs2BasicRequest import Gs2BasicRequest
from gs2_gacha_client.Gs2Gacha import Gs2Gacha


class UpdateGachaMasterRequest(Gs2BasicRequest):

    class Constant(Gs2Gacha):
        FUNCTION = "UpdateGachaMaster"

    def __init__(self, params=None):
        """
        コンストラクタ
        :param params: 辞書配列形式のパラメータ初期値リスト
        :type params: dict|None
        """
        super(UpdateGachaMasterRequest, self).__init__(params)
        if params is None:
            self.__gacha_pool_name = None
        else:
            self.set_gacha_pool_name(params['gachaPoolName'] if 'gachaPoolName' in params.keys() else None)
        if params is None:
            self.__gacha_name = None
        else:
            self.set_gacha_name(params['gachaName'] if 'gachaName' in params.keys() else None)
        if params is None:
            self.__meta = None
        else:
            self.set_meta(params['meta'] if 'meta' in params.keys() else None)
        if params is None:
            self.__prize_table_names = None
        else:
            self.set_prize_table_names(params['prizeTableNames'] if 'prizeTableNames' in params.keys() else None)
        if params is None:
            self.__prize_job_queue_name = None
        else:
            self.set_prize_job_queue_name(params['prizeJobQueueName'] if 'prizeJobQueueName' in params.keys() else None)
        if params is None:
            self.__prize_job_queue_script_name = None
        else:
            self.set_prize_job_queue_script_name(params['prizeJobQueueScriptName'] if 'prizeJobQueueScriptName' in params.keys() else None)

    def get_gacha_pool_name(self):
        """
        ガチャプールの名前を指定します。を取得
        :return: ガチャプールの名前を指定します。
        :rtype: unicode
        """
        return self.__gacha_pool_name

    def set_gacha_pool_name(self, gacha_pool_name):
        """
        ガチャプールの名前を指定します。を設定
        :param gacha_pool_name: ガチャプールの名前を指定します。
        :type gacha_pool_name: unicode
        """
        if gacha_pool_name is not None and not (isinstance(gacha_pool_name, str) or isinstance(gacha_pool_name, unicode)):
            raise TypeError(type(gacha_pool_name))
        self.__gacha_pool_name = gacha_pool_name

    def with_gacha_pool_name(self, gacha_pool_name):
        """
        ガチャプールの名前を指定します。を設定
        :param gacha_pool_name: ガチャプールの名前を指定します。
        :type gacha_pool_name: unicode
        :return: this
        :rtype: UpdateGachaMasterRequest
        """
        self.set_gacha_pool_name(gacha_pool_name)
        return self

    def get_gacha_name(self):
        """
        ガチャの名前を指定します。を取得
        :return: ガチャの名前を指定します。
        :rtype: unicode
        """
        return self.__gacha_name

    def set_gacha_name(self, gacha_name):
        """
        ガチャの名前を指定します。を設定
        :param gacha_name: ガチャの名前を指定します。
        :type gacha_name: unicode
        """
        if gacha_name is not None and not (isinstance(gacha_name, str) or isinstance(gacha_name, unicode)):
            raise TypeError(type(gacha_name))
        self.__gacha_name = gacha_name

    def with_gacha_name(self, gacha_name):
        """
        ガチャの名前を指定します。を設定
        :param gacha_name: ガチャの名前を指定します。
        :type gacha_name: unicode
        :return: this
        :rtype: UpdateGachaMasterRequest
        """
        self.set_gacha_name(gacha_name)
        return self

    def get_meta(self):
        """
        メタデータを取得
        :return: メタデータ
        :rtype: unicode
        """
        return self.__meta

    def set_meta(self, meta):
        """
        メタデータを設定
        :param meta: メタデータ
        :type meta: unicode
        """
        if meta is not None and not (isinstance(meta, str) or isinstance(meta, unicode)):
            raise TypeError(type(meta))
        self.__meta = meta

    def with_meta(self, meta):
        """
        メタデータを設定
        :param meta: メタデータ
        :type meta: unicode
        :return: this
        :rtype: UpdateGachaMasterRequest
        """
        self.set_meta(meta)
        return self

    def get_prize_table_names(self):
        """
        排出確率名リストを取得
        :return: 排出確率名リスト
        :rtype: list[unicode]
        """
        return self.__prize_table_names

    def set_prize_table_names(self, prize_table_names):
        """
        排出確率名リストを設定
        :param prize_table_names: 排出確率名リスト
        :type prize_table_names: list[unicode]
        """
        if prize_table_names is not None and not isinstance(prize_table_names, list):
            raise TypeError(type(prize_table_names))
        self.__prize_table_names = prize_table_names

    def with_prize_table_names(self, prize_table_names):
        """
        排出確率名リストを設定
        :param prize_table_names: 排出確率名リスト
        :type prize_table_names: list[unicode]
        :return: this
        :rtype: UpdateGachaMasterRequest
        """
        self.set_prize_table_names(prize_table_names)
        return self

    def get_prize_job_queue_name(self):
        """
        景品の排出処理に使用する GS2-JobQueueを取得
        :return: 景品の排出処理に使用する GS2-JobQueue
        :rtype: unicode
        """
        return self.__prize_job_queue_name

    def set_prize_job_queue_name(self, prize_job_queue_name):
        """
        景品の排出処理に使用する GS2-JobQueueを設定
        :param prize_job_queue_name: 景品の排出処理に使用する GS2-JobQueue
        :type prize_job_queue_name: unicode
        """
        if prize_job_queue_name is not None and not (isinstance(prize_job_queue_name, str) or isinstance(prize_job_queue_name, unicode)):
            raise TypeError(type(prize_job_queue_name))
        self.__prize_job_queue_name = prize_job_queue_name

    def with_prize_job_queue_name(self, prize_job_queue_name):
        """
        景品の排出処理に使用する GS2-JobQueueを設定
        :param prize_job_queue_name: 景品の排出処理に使用する GS2-JobQueue
        :type prize_job_queue_name: unicode
        :return: this
        :rtype: UpdateGachaMasterRequest
        """
        self.set_prize_job_queue_name(prize_job_queue_name)
        return self

    def get_prize_job_queue_script_name(self):
        """
        景品の排出処理に使用する GS2-JobQueue に指定する GS2-Scriptを取得
        :return: 景品の排出処理に使用する GS2-JobQueue に指定する GS2-Script
        :rtype: unicode
        """
        return self.__prize_job_queue_script_name

    def set_prize_job_queue_script_name(self, prize_job_queue_script_name):
        """
        景品の排出処理に使用する GS2-JobQueue に指定する GS2-Scriptを設定
        :param prize_job_queue_script_name: 景品の排出処理に使用する GS2-JobQueue に指定する GS2-Script
        :type prize_job_queue_script_name: unicode
        """
        if prize_job_queue_script_name is not None and not (isinstance(prize_job_queue_script_name, str) or isinstance(prize_job_queue_script_name, unicode)):
            raise TypeError(type(prize_job_queue_script_name))
        self.__prize_job_queue_script_name = prize_job_queue_script_name

    def with_prize_job_queue_script_name(self, prize_job_queue_script_name):
        """
        景品の排出処理に使用する GS2-JobQueue に指定する GS2-Scriptを設定
        :param prize_job_queue_script_name: 景品の排出処理に使用する GS2-JobQueue に指定する GS2-Script
        :type prize_job_queue_script_name: unicode
        :return: this
        :rtype: UpdateGachaMasterRequest
        """
        self.set_prize_job_queue_script_name(prize_job_queue_script_name)
        return self
