# encoding: utf-8
#
# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from gs2_core_client.Gs2BasicRequest import Gs2BasicRequest
from gs2_gacha_client.Gs2Gacha import Gs2Gacha


class UpdatePrizeMasterRequest(Gs2BasicRequest):

    class Constant(Gs2Gacha):
        FUNCTION = "UpdatePrizeMaster"

    def __init__(self, params=None):
        """
        コンストラクタ
        :param params: 辞書配列形式のパラメータ初期値リスト
        :type params: dict|None
        """
        super(UpdatePrizeMasterRequest, self).__init__(params)
        if params is None:
            self.__gacha_pool_name = None
        else:
            self.set_gacha_pool_name(params['gachaPoolName'] if 'gachaPoolName' in params.keys() else None)
        if params is None:
            self.__prize_table_name = None
        else:
            self.set_prize_table_name(params['prizeTableName'] if 'prizeTableName' in params.keys() else None)
        if params is None:
            self.__rarity_name = None
        else:
            self.set_rarity_name(params['rarityName'] if 'rarityName' in params.keys() else None)
        if params is None:
            self.__resource_id = None
        else:
            self.set_resource_id(params['resourceId'] if 'resourceId' in params.keys() else None)
        if params is None:
            self.__weight = None
        else:
            self.set_weight(params['weight'] if 'weight' in params.keys() else None)

    def get_gacha_pool_name(self):
        """
        ガチャプールの名前を指定します。を取得
        :return: ガチャプールの名前を指定します。
        :rtype: unicode
        """
        return self.__gacha_pool_name

    def set_gacha_pool_name(self, gacha_pool_name):
        """
        ガチャプールの名前を指定します。を設定
        :param gacha_pool_name: ガチャプールの名前を指定します。
        :type gacha_pool_name: unicode
        """
        if gacha_pool_name is not None and not (isinstance(gacha_pool_name, str) or isinstance(gacha_pool_name, unicode)):
            raise TypeError(type(gacha_pool_name))
        self.__gacha_pool_name = gacha_pool_name

    def with_gacha_pool_name(self, gacha_pool_name):
        """
        ガチャプールの名前を指定します。を設定
        :param gacha_pool_name: ガチャプールの名前を指定します。
        :type gacha_pool_name: unicode
        :return: this
        :rtype: UpdatePrizeMasterRequest
        """
        self.set_gacha_pool_name(gacha_pool_name)
        return self

    def get_prize_table_name(self):
        """
        排出確率テーブルの名前を指定します。を取得
        :return: 排出確率テーブルの名前を指定します。
        :rtype: unicode
        """
        return self.__prize_table_name

    def set_prize_table_name(self, prize_table_name):
        """
        排出確率テーブルの名前を指定します。を設定
        :param prize_table_name: 排出確率テーブルの名前を指定します。
        :type prize_table_name: unicode
        """
        if prize_table_name is not None and not (isinstance(prize_table_name, str) or isinstance(prize_table_name, unicode)):
            raise TypeError(type(prize_table_name))
        self.__prize_table_name = prize_table_name

    def with_prize_table_name(self, prize_table_name):
        """
        排出確率テーブルの名前を指定します。を設定
        :param prize_table_name: 排出確率テーブルの名前を指定します。
        :type prize_table_name: unicode
        :return: this
        :rtype: UpdatePrizeMasterRequest
        """
        self.set_prize_table_name(prize_table_name)
        return self

    def get_rarity_name(self):
        """
        景品レアリティの名前を指定します。を取得
        :return: 景品レアリティの名前を指定します。
        :rtype: unicode
        """
        return self.__rarity_name

    def set_rarity_name(self, rarity_name):
        """
        景品レアリティの名前を指定します。を設定
        :param rarity_name: 景品レアリティの名前を指定します。
        :type rarity_name: unicode
        """
        if rarity_name is not None and not (isinstance(rarity_name, str) or isinstance(rarity_name, unicode)):
            raise TypeError(type(rarity_name))
        self.__rarity_name = rarity_name

    def with_rarity_name(self, rarity_name):
        """
        景品レアリティの名前を指定します。を設定
        :param rarity_name: 景品レアリティの名前を指定します。
        :type rarity_name: unicode
        :return: this
        :rtype: UpdatePrizeMasterRequest
        """
        self.set_rarity_name(rarity_name)
        return self

    def get_resource_id(self):
        """
        リソースIDを指定します。を取得
        :return: リソースIDを指定します。
        :rtype: unicode
        """
        return self.__resource_id

    def set_resource_id(self, resource_id):
        """
        リソースIDを指定します。を設定
        :param resource_id: リソースIDを指定します。
        :type resource_id: unicode
        """
        if resource_id is not None and not (isinstance(resource_id, str) or isinstance(resource_id, unicode)):
            raise TypeError(type(resource_id))
        self.__resource_id = resource_id

    def with_resource_id(self, resource_id):
        """
        リソースIDを指定します。を設定
        :param resource_id: リソースIDを指定します。
        :type resource_id: unicode
        :return: this
        :rtype: UpdatePrizeMasterRequest
        """
        self.set_resource_id(resource_id)
        return self

    def get_weight(self):
        """
        排出重みを取得
        :return: 排出重み
        :rtype: int
        """
        return self.__weight

    def set_weight(self, weight):
        """
        排出重みを設定
        :param weight: 排出重み
        :type weight: int
        """
        if weight is not None and not isinstance(weight, int):
            raise TypeError(type(weight))
        self.__weight = weight

    def with_weight(self, weight):
        """
        排出重みを設定
        :param weight: 排出重み
        :type weight: int
        :return: this
        :rtype: UpdatePrizeMasterRequest
        """
        self.set_weight(weight)
        return self
