# encoding: utf-8
#
# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.


class Gacha(object):

    def __init__(self, params=None):
        if params is None:
            self.__name = None
            self.__meta = None
            self.__draw_count = None
        else:
            self.set_name(params['name'] if 'name' in params.keys() else None)
            self.set_meta(params['meta'] if 'meta' in params.keys() else None)
            self.set_draw_count(params['drawCount'] if 'drawCount' in params.keys() else None)

    def get_name(self):
        """
        ガチャ名を取得
        :return: ガチャ名
        :rtype: unicode
        """
        return self.__name

    def set_name(self, name):
        """
        ガチャ名を設定
        :param name: ガチャ名
        :type name: unicode
        """
        self.__name = name

    def get_meta(self):
        """
        メタデータを取得
        :return: メタデータ
        :rtype: unicode
        """
        return self.__meta

    def set_meta(self, meta):
        """
        メタデータを設定
        :param meta: メタデータ
        :type meta: unicode
        """
        self.__meta = meta

    def get_draw_count(self):
        """
        抽選回数を取得
        :return: 抽選回数
        :rtype: int
        """
        return self.__draw_count

    def set_draw_count(self, draw_count):
        """
        抽選回数を設定
        :param draw_count: 抽選回数
        :type draw_count: int
        """
        self.__draw_count = draw_count

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return super(Gacha, self).__getitem__(key)

    def to_dict(self):
        return {
            "name": self.__name,
            "meta": self.__meta,
            "drawCount": self.__draw_count,
        }
