# encoding: utf-8
#
# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.


class GachaMaster(object):

    def __init__(self, params=None):
        if params is None:
            self.__gacha_id = None
            self.__name = None
            self.__meta = None
            self.__prize_table_names = None
            self.__prize_job_queue_name = None
            self.__prize_job_queue_script_name = None
            self.__create_at = None
            self.__update_at = None
        else:
            self.set_gacha_id(params['gachaId'] if 'gachaId' in params.keys() else None)
            self.set_name(params['name'] if 'name' in params.keys() else None)
            self.set_meta(params['meta'] if 'meta' in params.keys() else None)
            self.set_prize_table_names(params['prizeTableNames'] if 'prizeTableNames' in params.keys() else None)
            self.set_prize_job_queue_name(params['prizeJobQueueName'] if 'prizeJobQueueName' in params.keys() else None)
            self.set_prize_job_queue_script_name(params['prizeJobQueueScriptName'] if 'prizeJobQueueScriptName' in params.keys() else None)
            self.set_create_at(params['createAt'] if 'createAt' in params.keys() else None)
            self.set_update_at(params['updateAt'] if 'updateAt' in params.keys() else None)

    def get_gacha_id(self):
        """
        ガチャGRNを取得
        :return: ガチャGRN
        :rtype: unicode
        """
        return self.__gacha_id

    def set_gacha_id(self, gacha_id):
        """
        ガチャGRNを設定
        :param gacha_id: ガチャGRN
        :type gacha_id: unicode
        """
        self.__gacha_id = gacha_id

    def get_name(self):
        """
        ガチャ名を取得
        :return: ガチャ名
        :rtype: unicode
        """
        return self.__name

    def set_name(self, name):
        """
        ガチャ名を設定
        :param name: ガチャ名
        :type name: unicode
        """
        self.__name = name

    def get_meta(self):
        """
        メタデータを取得
        :return: メタデータ
        :rtype: unicode
        """
        return self.__meta

    def set_meta(self, meta):
        """
        メタデータを設定
        :param meta: メタデータ
        :type meta: unicode
        """
        self.__meta = meta

    def get_prize_table_names(self):
        """
        排出確率名リストを取得
        :return: 排出確率名リスト
        :rtype: list[unicode]
        """
        return self.__prize_table_names

    def set_prize_table_names(self, prize_table_names):
        """
        排出確率名リストを設定
        :param prize_table_names: 排出確率名リスト
        :type prize_table_names: list[unicode]
        """
        self.__prize_table_names = prize_table_names

    def get_prize_job_queue_name(self):
        """
        景品の排出処理に使用する GS2-JobQueueを取得
        :return: 景品の排出処理に使用する GS2-JobQueue
        :rtype: unicode
        """
        return self.__prize_job_queue_name

    def set_prize_job_queue_name(self, prize_job_queue_name):
        """
        景品の排出処理に使用する GS2-JobQueueを設定
        :param prize_job_queue_name: 景品の排出処理に使用する GS2-JobQueue
        :type prize_job_queue_name: unicode
        """
        self.__prize_job_queue_name = prize_job_queue_name

    def get_prize_job_queue_script_name(self):
        """
        景品の排出処理に使用する GS2-JobQueue に指定する GS2-Scriptを取得
        :return: 景品の排出処理に使用する GS2-JobQueue に指定する GS2-Script
        :rtype: unicode
        """
        return self.__prize_job_queue_script_name

    def set_prize_job_queue_script_name(self, prize_job_queue_script_name):
        """
        景品の排出処理に使用する GS2-JobQueue に指定する GS2-Scriptを設定
        :param prize_job_queue_script_name: 景品の排出処理に使用する GS2-JobQueue に指定する GS2-Script
        :type prize_job_queue_script_name: unicode
        """
        self.__prize_job_queue_script_name = prize_job_queue_script_name

    def get_create_at(self):
        """
        作成日時(エポック秒)を取得
        :return: 作成日時(エポック秒)
        :rtype: int
        """
        return self.__create_at

    def set_create_at(self, create_at):
        """
        作成日時(エポック秒)を設定
        :param create_at: 作成日時(エポック秒)
        :type create_at: int
        """
        self.__create_at = create_at

    def get_update_at(self):
        """
        最終更新日時(エポック秒)を取得
        :return: 最終更新日時(エポック秒)
        :rtype: int
        """
        return self.__update_at

    def set_update_at(self, update_at):
        """
        最終更新日時(エポック秒)を設定
        :param update_at: 最終更新日時(エポック秒)
        :type update_at: int
        """
        self.__update_at = update_at

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return super(GachaMaster, self).__getitem__(key)

    def to_dict(self):
        return {
            "gachaId": self.__gacha_id,
            "name": self.__name,
            "meta": self.__meta,
            "prizeTableNames": self.__prize_table_names,
            "prizeJobQueueName": self.__prize_job_queue_name,
            "prizeJobQueueScriptName": self.__prize_job_queue_script_name,
            "createAt": self.__create_at,
            "updateAt": self.__update_at,
        }
