# encoding: utf-8
#
# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.


class GachaPool(object):

    def __init__(self, params=None):
        if params is None:
            self.__gacha_pool_id = None
            self.__owner_id = None
            self.__name = None
            self.__description = None
            self.__public_draw_rate = None
            self.__allow_access_gacha_info = None
            self.__restrict = None
            self.__draw_prize_trigger_script = None
            self.__draw_prize_done_trigger_script = None
            self.__create_at = None
            self.__update_at = None
        else:
            self.set_gacha_pool_id(params['gachaPoolId'] if 'gachaPoolId' in params.keys() else None)
            self.set_owner_id(params['ownerId'] if 'ownerId' in params.keys() else None)
            self.set_name(params['name'] if 'name' in params.keys() else None)
            self.set_description(params['description'] if 'description' in params.keys() else None)
            self.set_public_draw_rate(params['publicDrawRate'] if 'publicDrawRate' in params.keys() else None)
            self.set_allow_access_gacha_info(params['allowAccessGachaInfo'] if 'allowAccessGachaInfo' in params.keys() else None)
            self.set_restrict(params['restrict'] if 'restrict' in params.keys() else None)
            self.set_draw_prize_trigger_script(params['drawPrizeTriggerScript'] if 'drawPrizeTriggerScript' in params.keys() else None)
            self.set_draw_prize_done_trigger_script(params['drawPrizeDoneTriggerScript'] if 'drawPrizeDoneTriggerScript' in params.keys() else None)
            self.set_create_at(params['createAt'] if 'createAt' in params.keys() else None)
            self.set_update_at(params['updateAt'] if 'updateAt' in params.keys() else None)

    def get_gacha_pool_id(self):
        """
        ガチャプールGRNを取得
        :return: ガチャプールGRN
        :rtype: unicode
        """
        return self.__gacha_pool_id

    def set_gacha_pool_id(self, gacha_pool_id):
        """
        ガチャプールGRNを設定
        :param gacha_pool_id: ガチャプールGRN
        :type gacha_pool_id: unicode
        """
        self.__gacha_pool_id = gacha_pool_id

    def get_owner_id(self):
        """
        オーナーIDを取得
        :return: オーナーID
        :rtype: unicode
        """
        return self.__owner_id

    def set_owner_id(self, owner_id):
        """
        オーナーIDを設定
        :param owner_id: オーナーID
        :type owner_id: unicode
        """
        self.__owner_id = owner_id

    def get_name(self):
        """
        ガチャプール名を取得
        :return: ガチャプール名
        :rtype: unicode
        """
        return self.__name

    def set_name(self, name):
        """
        ガチャプール名を設定
        :param name: ガチャプール名
        :type name: unicode
        """
        self.__name = name

    def get_description(self):
        """
        説明文を取得
        :return: 説明文
        :rtype: unicode
        """
        return self.__description

    def set_description(self, description):
        """
        説明文を設定
        :param description: 説明文
        :type description: unicode
        """
        self.__description = description

    def get_public_draw_rate(self):
        """
        排出確率を公開するかを取得
        :return: 排出確率を公開するか
        :rtype: unicode
        """
        return self.__public_draw_rate

    def set_public_draw_rate(self, public_draw_rate):
        """
        排出確率を公開するかを設定
        :param public_draw_rate: 排出確率を公開するか
        :type public_draw_rate: unicode
        """
        self.__public_draw_rate = public_draw_rate

    def get_allow_access_gacha_info(self):
        """
        ガチャ一覧の取得を許すかを取得
        :return: ガチャ一覧の取得を許すか
        :rtype: unicode
        """
        return self.__allow_access_gacha_info

    def set_allow_access_gacha_info(self, allow_access_gacha_info):
        """
        ガチャ一覧の取得を許すかを設定
        :param allow_access_gacha_info: ガチャ一覧の取得を許すか
        :type allow_access_gacha_info: unicode
        """
        self.__allow_access_gacha_info = allow_access_gacha_info

    def get_restrict(self):
        """
        抽選実行を制限するかを取得
        :return: 抽選実行を制限するか
        :rtype: unicode
        """
        return self.__restrict

    def set_restrict(self, restrict):
        """
        抽選実行を制限するかを設定
        :param restrict: 抽選実行を制限するか
        :type restrict: unicode
        """
        self.__restrict = restrict

    def get_draw_prize_trigger_script(self):
        """
        排出判定時 に実行されるGS2-Scriptを取得
        :return: 排出判定時 に実行されるGS2-Script
        :rtype: unicode
        """
        return self.__draw_prize_trigger_script

    def set_draw_prize_trigger_script(self, draw_prize_trigger_script):
        """
        排出判定時 に実行されるGS2-Scriptを設定
        :param draw_prize_trigger_script: 排出判定時 に実行されるGS2-Script
        :type draw_prize_trigger_script: unicode
        """
        self.__draw_prize_trigger_script = draw_prize_trigger_script

    def get_draw_prize_done_trigger_script(self):
        """
        排出判定完了時 に実行されるGS2-Scriptを取得
        :return: 排出判定完了時 に実行されるGS2-Script
        :rtype: unicode
        """
        return self.__draw_prize_done_trigger_script

    def set_draw_prize_done_trigger_script(self, draw_prize_done_trigger_script):
        """
        排出判定完了時 に実行されるGS2-Scriptを設定
        :param draw_prize_done_trigger_script: 排出判定完了時 に実行されるGS2-Script
        :type draw_prize_done_trigger_script: unicode
        """
        self.__draw_prize_done_trigger_script = draw_prize_done_trigger_script

    def get_create_at(self):
        """
        作成日時(エポック秒)を取得
        :return: 作成日時(エポック秒)
        :rtype: int
        """
        return self.__create_at

    def set_create_at(self, create_at):
        """
        作成日時(エポック秒)を設定
        :param create_at: 作成日時(エポック秒)
        :type create_at: int
        """
        self.__create_at = create_at

    def get_update_at(self):
        """
        最終更新日時(エポック秒)を取得
        :return: 最終更新日時(エポック秒)
        :rtype: int
        """
        return self.__update_at

    def set_update_at(self, update_at):
        """
        最終更新日時(エポック秒)を設定
        :param update_at: 最終更新日時(エポック秒)
        :type update_at: int
        """
        self.__update_at = update_at

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return super(GachaPool, self).__getitem__(key)

    def to_dict(self):
        return {
            "gachaPoolId": self.__gacha_pool_id,
            "ownerId": self.__owner_id,
            "name": self.__name,
            "description": self.__description,
            "publicDrawRate": self.__public_draw_rate,
            "allowAccessGachaInfo": self.__allow_access_gacha_info,
            "restrict": self.__restrict,
            "drawPrizeTriggerScript": self.__draw_prize_trigger_script,
            "drawPrizeDoneTriggerScript": self.__draw_prize_done_trigger_script,
            "createAt": self.__create_at,
            "updateAt": self.__update_at,
        }
