# encoding: utf-8
#
# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.


class PrizeMaster(object):

    def __init__(self, params=None):
        if params is None:
            self.__prize_id = None
            self.__resource_id = None
            self.__weight = None
            self.__create_at = None
            self.__update_at = None
        else:
            self.set_prize_id(params['prizeId'] if 'prizeId' in params.keys() else None)
            self.set_resource_id(params['resourceId'] if 'resourceId' in params.keys() else None)
            self.set_weight(params['weight'] if 'weight' in params.keys() else None)
            self.set_create_at(params['createAt'] if 'createAt' in params.keys() else None)
            self.set_update_at(params['updateAt'] if 'updateAt' in params.keys() else None)

    def get_prize_id(self):
        """
        景品GRNを取得
        :return: 景品GRN
        :rtype: unicode
        """
        return self.__prize_id

    def set_prize_id(self, prize_id):
        """
        景品GRNを設定
        :param prize_id: 景品GRN
        :type prize_id: unicode
        """
        self.__prize_id = prize_id

    def get_resource_id(self):
        """
        リソースIDを取得
        :return: リソースID
        :rtype: unicode
        """
        return self.__resource_id

    def set_resource_id(self, resource_id):
        """
        リソースIDを設定
        :param resource_id: リソースID
        :type resource_id: unicode
        """
        self.__resource_id = resource_id

    def get_weight(self):
        """
        排出重みを取得
        :return: 排出重み
        :rtype: int
        """
        return self.__weight

    def set_weight(self, weight):
        """
        排出重みを設定
        :param weight: 排出重み
        :type weight: int
        """
        self.__weight = weight

    def get_create_at(self):
        """
        作成日時(エポック秒)を取得
        :return: 作成日時(エポック秒)
        :rtype: int
        """
        return self.__create_at

    def set_create_at(self, create_at):
        """
        作成日時(エポック秒)を設定
        :param create_at: 作成日時(エポック秒)
        :type create_at: int
        """
        self.__create_at = create_at

    def get_update_at(self):
        """
        最終更新日時(エポック秒)を取得
        :return: 最終更新日時(エポック秒)
        :rtype: int
        """
        return self.__update_at

    def set_update_at(self, update_at):
        """
        最終更新日時(エポック秒)を設定
        :param update_at: 最終更新日時(エポック秒)
        :type update_at: int
        """
        self.__update_at = update_at

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return super(PrizeMaster, self).__getitem__(key)

    def to_dict(self):
        return {
            "prizeId": self.__prize_id,
            "resourceId": self.__resource_id,
            "weight": self.__weight,
            "createAt": self.__create_at,
            "updateAt": self.__update_at,
        }
