# encoding: utf-8
#
# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.


class RarityMaster(object):

    def __init__(self, params=None):
        if params is None:
            self.__rarity_id = None
            self.__name = None
            self.__weight = None
            self.__create_at = None
            self.__update_at = None
        else:
            self.set_rarity_id(params['rarityId'] if 'rarityId' in params.keys() else None)
            self.set_name(params['name'] if 'name' in params.keys() else None)
            self.set_weight(params['weight'] if 'weight' in params.keys() else None)
            self.set_create_at(params['createAt'] if 'createAt' in params.keys() else None)
            self.set_update_at(params['updateAt'] if 'updateAt' in params.keys() else None)

    def get_rarity_id(self):
        """
        景品レアリティGRNを取得
        :return: 景品レアリティGRN
        :rtype: unicode
        """
        return self.__rarity_id

    def set_rarity_id(self, rarity_id):
        """
        景品レアリティGRNを設定
        :param rarity_id: 景品レアリティGRN
        :type rarity_id: unicode
        """
        self.__rarity_id = rarity_id

    def get_name(self):
        """
        景品レアリティ名を取得
        :return: 景品レアリティ名
        :rtype: unicode
        """
        return self.__name

    def set_name(self, name):
        """
        景品レアリティ名を設定
        :param name: 景品レアリティ名
        :type name: unicode
        """
        self.__name = name

    def get_weight(self):
        """
        排出重みを取得
        :return: 排出重み
        :rtype: int
        """
        return self.__weight

    def set_weight(self, weight):
        """
        排出重みを設定
        :param weight: 排出重み
        :type weight: int
        """
        self.__weight = weight

    def get_create_at(self):
        """
        作成日時(エポック秒)を取得
        :return: 作成日時(エポック秒)
        :rtype: int
        """
        return self.__create_at

    def set_create_at(self, create_at):
        """
        作成日時(エポック秒)を設定
        :param create_at: 作成日時(エポック秒)
        :type create_at: int
        """
        self.__create_at = create_at

    def get_update_at(self):
        """
        最終更新日時(エポック秒)を取得
        :return: 最終更新日時(エポック秒)
        :rtype: int
        """
        return self.__update_at

    def set_update_at(self, update_at):
        """
        最終更新日時(エポック秒)を設定
        :param update_at: 最終更新日時(エポック秒)
        :type update_at: int
        """
        self.__update_at = update_at

    def __getitem__(self, key):
        items = self.to_dict()
        if key in items.keys():
            return items[key]
        return super(RarityMaster, self).__getitem__(key)

    def to_dict(self):
        return {
            "rarityId": self.__rarity_id,
            "name": self.__name,
            "weight": self.__weight,
            "createAt": self.__create_at,
            "updateAt": self.__update_at,
        }
